@@ -338,43 +338,3 @@ func TestConfigTemplate_MergeTo(t *testing.T) {
 		})
 	}
 }
-
-// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/6404
-func TestDockerServiceFlags(t *testing.T) {
-	mNetwork := new(common.MockNetwork)
-	defer mNetwork.AssertExpectations(t)
-	mNetwork.On("RegisterRunner", mock.Anything, mock.Anything).
-		Return(&common.RegisterRunnerResponse{
-			Token: "test-runner-token",
-		}).
-		Once()
-
-	cmd := newRegisterCommand()
-	cmd.network = mNetwork
-
-	app := cli.NewApp()
-	app.Commands = []cli.Command{
-		{
-			Name:   "register",
-			Action: cmd.Execute,
-			Flags:  clihelpers.GetFlagsFromStruct(cmd),
-		},
-	}
-
-	args := []string{
-		"binary", "register",
-		"-n",
-		"--url", "http://gitlab.example.com/",
-		"--registration-token", "test-registration-token",
-		"--executor", "docker",
-		"--docker-image", "alpine:3.11",
-		"--docker-services", "alpine:3.11",
-		"--docker-services", "ruby:2.6",
-	}
-
-	err := app.Run(args)
-	require.NoError(t, err)
-
-	assert.Equal(t, "alpine:3.11", cmd.Docker.Services[0].Name)
-	assert.Equal(t, "ruby:2.6", cmd.Docker.Services[1].Name)
-}
