@@ -40,7 +40,7 @@ func newDefaultManager(config ManagerConfig) *manager {
 	m := &manager{
 		logger:         newDebugLoggerMock(),
 		config:         config,
-		managedVolumes: make(map[string]bool, 0),
+		managedVolumes: make(map[string]bool),
 	}
 
 	return m
